FileResultTracker
=================

.. currentmodule:: pykeen.trackers

.. autoclass:: FileResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FileResultTracker.end_run

   .. rubric:: Methods Documentation

   .. automethod:: end_run
